@@ -10,10 +10,10 @@ OC.L10N.register(
     "Open »%s«" : "فتح »%s«",
     "Cheers!" : "تحياتي!",
     "Upcoming events" : "الفعاليات القادمة",
+    "Calendar" : "التقويم",
     "Appointments" : "المواعيد",
     "Confirm" : "تأكيد",
     "Date:" : "التاريخ:",
-    "Calendar" : "التقويم",
     "A Calendar app for Nextcloud" : "تطبيق التقويم لـ نكست كلاود",
     "Previous day" : "اليوم الماضي",
     "Previous week" : "الاسبوع الماضي",
@@ -144,6 +144,10 @@ OC.L10N.register(
     "at" : "في",
     "+ Add reminder" : "+ اضافة تذكير",
     "_second_::_seconds_" : ["ثانية","ثانية","ثانية","ثواني","ثواني","ثواني"],
+    "Add from Files" : "إضافة من الملفات",
+    "Delete file" : "احذف الملف",
+    "Choose a file to add as attachment" : "اختر ملف لإضافته كمرفق",
+    "Choose a file to share as a link" : "اختر ملفا لمشاركته كرابط",
     "Available" : "متوفر",
     "Not available" : "غير متوفر",
     "Availability of attendees, resources and rooms" : "متوفرين من الحضور والموارد والغرف",
@@ -292,6 +296,7 @@ OC.L10N.register(
     "Add this as a new category" : "اضف كـ تصنيف جديد",
     "Custom color" : "لون خاص",
     "Special color of this event. Overrides the calendar-color." : "اللون الخاص للفعالية هذه، يعيد تعيين لون التقويم.",
+    "Error while sharing file" : "خطأ اثناء مشاركة ملف",
     "Chat room for event" : "غرفة محادثة للفعالية",
     "An error occurred, unable to delete the calendar." : "حدث خطأ، لا يمكن حذف التقويم.",
     "Imported {filename}" : "استيراد {filename}",
