@@ -10,8 +10,8 @@ OC.L10N.register(
     "Open »%s«" : "Digeriñ  »%s«",
     "Cheers!" : "A galon !",
     "Upcoming events" : "Darvoudoù da zont",
-    "Confirm" : "Kadarnañ",
     "Calendar" : "Deiziataer",
+    "Confirm" : "Kadarnañ",
     "A Calendar app for Nextcloud" : "Un arload Deiziataerioù evit Nextcloud",
     "Previous day" : "Deizioù kent",
     "Previous week" : "Sizhun kent",
@@ -29,31 +29,33 @@ OC.L10N.register(
     "Edit" : "Cheñch",
     "Delete" : "Dilemel",
     "Untitled calendar" : "Deiziataer hep titl",
-    "Edit name" : "Embann an anv",
-    "Saving name …" : "Oc'h enrollañ an anv  ...",
-    "Edit color" : "Embann al liv",
-    "Saving color …" : "Enrollañ al liv   ...",
-    "Copy private link" : "Eilañ al liamm prevez",
-    "Unshare from me" : "Paouez da lodañ ganin",
+    "Shared with you by" : "Rannet deoc'h gant",
     "An error occurred, unable to change visibility of the calendar." : "C'hoarvezet ez eus ur fazi, ne c'halletr ket kemmañ gweluster an deiziataer.",
-    "An error occurred, unable to delete the calendar." : "C'hoarvezet ez eus ur fazi, ne c'haller ket dilemel an deiziataer.",
-    "Calendar link copied to clipboard." : "Eilet eo bet liamm an deiziataer er golver",
-    "Calendar link could not be copied to clipboard." : "N'eus ket bet gallet eilañ liamm an deiziataer er golver",
-    "An error occurred, unable to rename the calendar." : "C'hoarvezet ez eus ur fazi, ne c'haller ket cheñch anv an deiziataer.",
-    "An error occurred, unable to change the calendar's color." : "C'hoarvezet ez eus ur fazi, ne c'haller ket cheñch liv an deiziataer.",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Paouezet e vo da lodañ an deiziataer a-benn {countdown} eilenn"],
     "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Dilamet e vo an deiziataer a-benn {countdown} eilenn"],
-    "Share link" : "Lodañ al liamm",
-    "Publish calendar" : "Embann an deiziataer",
-    "Publishing calendar" : "Oc'h embann an deiziataer",
-    "Copy public link" : "Eilañ al liamm foran",
-    "Send link to calendar via email" : "Kas al liamm d'an deiziataer dre bostel",
-    "Enter one address" : "Lakait ur chomlec'h",
-    "Sending email …" : "O kas ar postel  ... ",
+    "New calendar" : "Deizataer nevez",
+    "Creating calendar …" : "Krouiñ un deizataer ...",
+    "New calendar with task list" : "Deizataer nevez gant ur roll ober",
+    "New subscription from link (read-only)" : "Koumanant nevez dre liamm (lenn nemetken)",
+    "Creating subscription …" : "Krouiñ ur goumanant ...",
+    "An error occurred, unable to create the calendar." : "Ur fazi a zo bet, dibosupl eo krouiñ an deizataer",
+    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Lakait ul liamm mat (o kregiñ gant http://, https://, webcal://, or webcals://)",
     "Copy subscription link" : "Eilañ al liamm koumanantiñ",
     "Copying link …" : "Oc'h eilañ al liamm  ...",
     "Copied link" : "Liamm eilet",
     "Could not copy link" : "N'eus ket bet gallet eilañ al liamm",
+    "Calendar link copied to clipboard." : "Eilet eo bet liamm an deiziataer er golver",
+    "Calendar link could not be copied to clipboard." : "N'eus ket bet gallet eilañ liamm an deiziataer er golver",
+    "Name" : "Anv",
+    "Deleted" : "Lamet",
+    "Restore" : "Adkrouiñ",
+    "Delete permanently" : "Lamet da viken",
+    "Could not update calendar order." : "Dibosupl eo adnevesaat urzh an deizataerioù",
+    "Share link" : "Lodañ al liamm",
+    "Copy public link" : "Eilañ al liamm foran",
+    "Send link to calendar via email" : "Kas al liamm d'an deiziataer dre bostel",
+    "Enter one address" : "Lakait ur chomlec'h",
+    "Sending email …" : "O kas ar postel  ... ",
     "Copy embedding code" : "Eilañ ar c'hod enframmañ",
     "Copying code …" : "Oc'h eilañ ar c'hod ...",
     "Copied code" : "Kod eilet",
@@ -65,24 +67,14 @@ OC.L10N.register(
     "Embed code copied to clipboard." : "Eilet eo bet ar c'hod enframmañ er golver",
     "Embed code could not be copied to clipboard." : "N'eus ket bet gallet eilañ ar c'hod enframmañ er golver.",
     "Unpublishing calendar failed" : "Diembannaadur an deizataer c'hwited",
-    "Share with users or groups" : "Rannañ gant implijourienn pe strolladoù",
-    "No users or groups" : "Implijourienn pe strodadoù ebet",
     "can edit" : "posuple eo embann",
     "Unshare with {displayName}" : "Dirannañ gant {displayName}",
     "An error occurred, unable to change the unshare the calendar." : "Ur fazi a zo bet, dibosupl eo cheñch an deizataer dirannet.",
     "An error occurred, unable to change the permission of the share." : "Ur azi a zo bet, dibosupl eo cheñch aotreoù ar rannadenn.",
-    "New calendar" : "Deizataer nevez",
-    "Creating calendar …" : "Krouiñ un deizataer ...",
-    "New calendar with task list" : "Deizataer nevez gant ur roll ober",
-    "New subscription from link (read-only)" : "Koumanant nevez dre liamm (lenn nemetken)",
-    "Creating subscription …" : "Krouiñ ur goumanant ...",
-    "An error occurred, unable to create the calendar." : "Ur fazi a zo bet, dibosupl eo krouiñ an deizataer",
-    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Lakait ul liamm mat (o kregiñ gant http://, https://, webcal://, or webcals://)",
-    "Name" : "Anv",
-    "Deleted" : "Lamet",
-    "Restore" : "Adkrouiñ",
-    "Delete permanently" : "Lamet da viken",
-    "Could not update calendar order." : "Dibosupl eo adnevesaat urzh an deizataerioù",
+    "Share with users or groups" : "Rannañ gant implijourienn pe strolladoù",
+    "No users or groups" : "Implijourienn pe strodadoù ebet",
+    "Copy private link" : "Eilañ al liamm prevez",
+    "Unshare from me" : "Paouez da lodañ ganin",
     "Import calendars" : "Emporzhiañ deizataerioù",
     "Please select a calendar to import into …" : "Choazit un deizataer de emporzhiañ e-barzh ...",
     "Filename" : "Anv restr",
@@ -103,6 +95,7 @@ OC.L10N.register(
     "Your email address" : "O chom-lec'h postel",
     "Notification" : "Kemenadenn",
     "Email" : "Postel",
+    "Delete file" : "Dilemel ar restr",
     "Available" : "Vak",
     "Not available" : "Divak",
     "Free" : "Digoust",
@@ -156,7 +149,9 @@ OC.L10N.register(
     "Add this as a new category" : "Ouzhpennañ an dra-se evel ur rummad nevez",
     "Custom color" : "Liv personelaet",
     "Special color of this event. Overrides the calendar-color." : "Liv dibar evit an darvoud-mañ. Diverkañ liv an deiziataer",
+    "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr",
     "Chat room for event" : "Sal-flapiñ evit un darvoud",
+    "An error occurred, unable to delete the calendar." : "C'hoarvezet ez eus ur fazi, ne c'haller ket dilemel an deiziataer.",
     "Imported {filename}" : "Enporzhiet {filename}",
     "Meditation" : "Darvestiñ",
     "Relaxing" : "Distanañ",
