@@ -6,8 +6,8 @@ OC.L10N.register(
     "Open »%s«" : "Abrir »%s«",
     "Cheers!" : "¡Saludos!",
     "Upcoming events" : "Próximos eventos",
-    "Confirm" : "Confirmar",
     "Calendar" : "Calendario",
+    "Confirm" : "Confirmar",
     "A Calendar app for Nextcloud" : "Una aplicación de calendario para Nextcloud",
     "Previous day" : "Día previo",
     "Previous week" : "Semana previa",
@@ -61,6 +61,8 @@ OC.L10N.register(
     "Your email address" : "Su dirección de correo electrónico",
     "Notification" : "Notificación",
     "Email" : "Correo electrónico",
+    "Delete file" : "Borrar archivo",
+    "Choose a file to add as attachment" : "Seleccione el archivo a agregar como adjunto",
     "Available" : "Disponible",
     "Unknown" : "Desconocido",
     "Accept" : "Aceptar",
