@@ -7,53 +7,84 @@ OC.L10N.register(
     "Open »%s«" : "Abrir »%s«",
     "Cheers!" : "¡Saludos!",
     "Calendar" : "Calendario",
+    "Confirm" : "Confirmar",
+    "Where:" : "Dónde:",
+    "New event" : "Nuevo evento",
     "Today" : "Hoy",
     "Day" : "Día",
     "Week" : "Semana",
     "Month" : "Mes",
     "List" : "Lista",
+    "Preview" : "Previsualizar",
+    "Copy link" : "Copiar liga",
+    "Edit" : "Editar",
     "Delete" : "Borrar",
-    "Download" : "Descargar",
-    "Share link" : "Compartir liga",
-    "Share with users or groups" : "Compartir con otros usuarios o grupos",
-    "can edit" : "puede editar",
     "New calendar" : "Nuevo calendario",
+    "Export" : "Exportar",
+    "Name" : "Nombre",
+    "Deleted" : "Borrado",
+    "Restore" : "Restaurar",
+    "Delete permanently" : "Borrar permanentemente",
+    "Share link" : "Compartir liga",
+    "can edit" : "puede editar",
+    "Share with users or groups" : "Compartir con otros usuarios o grupos",
     "Filename" : "Nombre del archivo",
     "Cancel" : "Cancelar",
     "Automatic" : "Automático",
     "or" : "o",
+    "List view" : "Vista de lista",
     "Actions" : "Acciones",
     "Show week numbers" : "Mostrar número de semana",
-    "Settings & import" : "Configuraciones & importar",
     "Location" : "Ubicación",
     "Description" : "Descripción",
+    "to" : "para",
+    "Add" : "Agregar",
     "Monday" : "Lunes",
+    "Tuesday" : "Martes",
+    "Wednesday" : "Miércoles",
+    "Thursday" : "Jueves",
+    "Friday" : "Viernes",
+    "Saturday" : "Sábado",
+    "Sunday" : "Domingo",
     "Save" : "Guardar",
     "Update" : "Actualizar",
+    "Your email address" : "Tu dirección de correo electrónico",
     "Notification" : "Notificación",
     "Email" : "Correo electrónico",
+    "Delete file" : "Borrar archivo",
+    "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
     "Unknown" : "Desconocido",
+    "Accept" : "Aceptar",
+    "Decline" : "Declinar",
     "Tentative" : "Tentativo",
+    "Send email" : "Enviar correo electrónico",
     "All day" : "Todo el día",
     "Repeat" : "Repetir",
     "never" : "nunca",
     "after" : "después",
+    "available" : "disponible",
     "More" : "Más",
     "Global" : "Global",
     "Personal" : "Personal",
     "Details" : "Detalles",
     "Attendees" : "Asistentes",
+    "Resources" : "Recursos",
     "Close" : "Cerrar",
     "Anniversary" : "Aniversario",
     "Week {number} of {year}" : "Semana {number} de {year}",
     "Daily" : "Diariamente",
     "Weekly" : "Semanalmente",
+    "Prev" : "Prev",
+    "Next" : "Siguiente",
+    "Other" : "Otro",
     "When shared show full event" : "Al compartir, mostrar el evento completo",
     "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
     "When shared hide this event" : "Al compartir, ocultar este evento ",
     "Status" : "Estatus",
     "Confirmed" : "Confirmado",
     "Categories" : "Categorías",
-    "Mail" : "Correo"
+    "Talk" : "Hablar",
+    "Mail" : "Correo",
+    "Birthday" : "Fecha de nacimiento"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
