@@ -6,9 +6,9 @@ OC.L10N.register(
     "We wanted to inform you that %s has published the calendar »%s«." : "Tahtsime Sind informeerida, et %s on avaldanud kalendri»%s«.",
     "Open »%s«" : "Ava »%s«",
     "Cheers!" : "Tervist!",
+    "Calendar" : "Kalender",
     "Confirm" : "Kinnita",
     "Where:" : "Kus:",
-    "Calendar" : "Kalender",
     "Previous day" : "Eelmine päev",
     "Previous week" : "Eelmine nädal",
     "Previous month" : "Eelmine kuu",
@@ -63,6 +63,8 @@ OC.L10N.register(
     "Notification" : "Teavitus",
     "Email" : "Epost",
     "On date" : "Kuupäeval",
+    "Delete file" : "Kustuta fail",
+    "Choose a file to add as attachment" : "Vali fail, mida manustada",
     "Unknown" : "Teadmata",
     "Accept" : "Nõustu",
     "Decline" : "Keeldu",
