@@ -10,11 +10,11 @@ OC.L10N.register(
     "Open »%s«" : "باز کن »%s«",
     "Cheers!" : "سلامتی!",
     "Upcoming events" : "رویدادهای پیش‌رو",
+    "Calendar" : "تقویم",
     "Appointments" : "قرارها",
     "Confirm" : "تائید",
     "Date:" : "تاریخ:",
     "Where:" : "مکان:",
-    "Calendar" : "تقویم",
     "A Calendar app for Nextcloud" : "یک برنامه تقویم برای نکست کلود",
     "Previous day" : "روز قبل",
     "Previous week" : "هفته قبل",
@@ -137,6 +137,8 @@ OC.L10N.register(
     "_hour_::_hours_" : ["ساعت","ساعت ها"],
     "_day_::_days_" : ["روز","روز ها"],
     "_week_::_weeks_" : ["هفته","هفته ها"],
+    "Delete file" : "حذف پرونده",
+    "Choose a file to add as attachment" : "پرونده ای را برای اضافه کردن به عنوان پیوست انتخاب کنید",
     "Available" : "در دسترس",
     "Availability of attendees, resources and rooms" : "در دسترس بودن شرکت کنندگان ، منابع و اتاق ها",
     "Free" : "رایگان",
