@@ -8,8 +8,8 @@ OC.L10N.register(
     "We wanted to inform you that %s has published the calendar »%s«." : "Kami ingin menginformasikan anda bahwa %s telah mempublikasikan kalender »%s«.",
     "Open »%s«" : "Buka »%s«",
     "Cheers!" : "Horee!",
-    "Confirm" : "Konfirmasi",
     "Calendar" : "Kalender",
+    "Confirm" : "Konfirmasi",
     "A Calendar app for Nextcloud" : "Aplikasi Kalender untuk Nextcloud",
     "Previous day" : "Hari sebelum",
     "Previous week" : "Minggu sebelum",
@@ -134,6 +134,8 @@ OC.L10N.register(
     "_hour_::_hours_" : ["jam"],
     "_day_::_days_" : ["hari"],
     "_week_::_weeks_" : ["minggu"],
+    "Delete file" : "Hapus berkas",
+    "Choose a file to add as attachment" : "Pilih berkas untuk ditambahkan sebagai lampiran",
     "Availability of attendees, resources and rooms" : "Ketersediaan peserta, sumber daya, dan ruangan",
     "Free" : "Luang",
     "Busy (tentative)" : "Sibuk (tentatif)",
