@@ -6,9 +6,9 @@ OC.L10N.register(
     "We wanted to inform you that %s has published the calendar »%s«." : "გვსურს შეგატყობინოთ, რომ %s მომხმარებელმა გამოაქყვენა კალენდარი »%s«.",
     "Open »%s«" : "გახნსნა »%s«",
     "Cheers!" : "წარმატებები!",
+    "Calendar" : "კალენდარი",
     "Confirm" : "დადასტურება",
     "Where:" : "სად:",
-    "Calendar" : "კალენდარი",
     "New event" : "ახალი მოვლენა",
     "Today" : "დღეს",
     "Day" : "დღე",
@@ -51,6 +51,8 @@ OC.L10N.register(
     "Your email address" : "თქვენი ელ-ფოსტის მისამართი",
     "Notification" : "შეტყობინება",
     "Email" : "ელ-ფოსტა",
+    "Delete file" : "გაუქმდეს ფაილი",
+    "Choose a file to add as attachment" : "დანართად დასამატებლად აირჩიეთ ფაილი",
     "Unknown" : "ამოუცნობი",
     "Accept" : "მიღება",
     "Decline" : "ურაყოფა",
