@@ -6,17 +6,34 @@ OC.L10N.register(
     "We wanted to inform you that %s has published the calendar »%s«." : "%s хэрэглэгч нь  »%s« календарийг нийтэлснийг үүгээр мэдэгдэе.",
     "Open »%s«" : "»%s« нээх",
     "Cheers!" : "Болж байна!",
-    "Confirm" : "Батлах",
+    "Upcoming events" : "Удахгүй болох үйл явдлууд",
     "Calendar" : "Календарь",
+    "Confirm" : "Батлах",
+    "This confirmation link expires in %s hours." : "Энэ баталгаажуулах холбоос %s цагийн дараа дуусна ",
+    "Date:" : "Огноо:",
+    "Where:" : " Хаана:",
+    "A Calendar app for Nextcloud" : "Нэкстклауд Календарь апп ",
+    "Previous day" : "Өмнөх өдөр",
+    "Previous week" : "Өнмөх 7 хоног",
+    "Previous month" : "Өмнөх сар",
+    "Next day" : "Маргааш",
+    "Next week" : "Дараа 7 хоног",
+    "Next month" : "Дараа сар",
     "New event" : "Шинэ үйл явдал",
     "Today" : "Өнөөдөр",
     "Day" : "Өдөр",
     "Week" : "Долоо хоног",
     "Month" : "Сар",
+    "List" : "Жагсаалт",
     "Preview" : "шалгах",
     "Copy link" : "Холбоос хуулах",
     "Edit" : "засварлах",
     "Delete" : "Устгах",
+    "Add new" : "Шинээр нэмэх",
+    "Shared with you by" : "Таньд хуваалцсан",
+    "Edit and share calendar" : " Календарь засварлах болон хуваалцах",
+    "Edit calendar" : "Календар засварлах",
+    "Disable calendar \"{calendar}\"" : "Кадендарь Идэвхигүй болгох \"{calendar}\"",
     "New calendar" : "Шинэ цагийн хуваарь",
     "Export" : "Экспорт",
     "Name" : "Нэр",
@@ -45,11 +62,13 @@ OC.L10N.register(
     "Update" : "Шинэчлэх",
     "Notification" : "Мэдэгдэл",
     "Email" : "Цахим шуудан",
+    "Delete file" : "Файл устгах",
     "Available" : "Боломжтой",
     "Unknown" : "Үл танигдах зүйл",
     "Accept" : "Хүлээн зөвшөөрөх",
     "Decline" : "Зөвшөөрөхгүй",
     "Tentative" : "Урьдчилсан тов",
+    "Send email" : "Мэйл илгээх",
     "Repeat" : "Давтах",
     "never" : "хэзээ ч үгүй",
     "after" : "дараа",
