@@ -5,11 +5,11 @@ OC.L10N.register(
     "Open »%s«" : "Dobrir « %s »",
     "Cheers!" : "A lèu !",
     "Upcoming events" : "Eveniments venents",
+    "Calendar" : "Calendièr",
     "Appointments" : "Rendetz-vos",
     "Confirm" : "Confirmar",
     "Date:" : "Data :",
     "Where:" : "Ont :",
-    "Calendar" : "Calendièr",
     "A Calendar app for Nextcloud" : "Una aplicacion de calendièr per Nextcloud",
     "Previous day" : "Jorn passat",
     "Previous week" : "Setmana passada",
@@ -90,6 +90,8 @@ OC.L10N.register(
     "_hour_::_hours_" : ["ora","oras"],
     "_day_::_days_" : ["jorn","jorns"],
     "_week_::_weeks_" : ["setmana","setmanas"],
+    "Delete file" : "Suprimir fichièr",
+    "Choose a file to add as attachment" : "Causissètz un fichièr de jónher al messatge",
     "Available" : "Disponible",
     "Free" : "Liure",
     "Busy (tentative)" : "Ocupat (provisòri)",
@@ -167,6 +169,7 @@ OC.L10N.register(
     "Canceled" : "Anullat",
     "Categories" : "Categorias",
     "Custom color" : "Color personalizada",
+    "Error while sharing file" : "Error pendent lo partiment del fichièr",
     "Commuting" : "En comunicacion",
     "Invoice" : "Factura",
     "Finance" : "Finança",
