@@ -6,10 +6,10 @@ OC.L10N.register(
     "We wanted to inform you that %s has published the calendar »%s«." : "Donim t'ju informonim se %s ka publikuar kalendarin »%s«",
     "Open »%s«" : "Hap »%s«",
     "Cheers!" : "Gëzuar!",
+    "Calendar" : "Kalendar",
     "Appointments" : "Takime",
     "Confirm" : "Konfirmo",
     "Where:" : "Ku:",
-    "Calendar" : "Kalendar",
     "New event" : "Veprimtari e re",
     "Today" : "Sot",
     "Day" : "Ditë",
@@ -52,6 +52,8 @@ OC.L10N.register(
     "Your email address" : "Adresa juaj email",
     "Notification" : "Njoftim",
     "Email" : "Emaili",
+    "Delete file" : "Fshi skedarin",
+    "Choose a file to add as attachment" : "Zgjidhni një kartelë që të shtohet si bashkëngjitje",
     "Available" : "i disponueshëm",
     "Unknown" : "I/E panjohur",
     "Accept" : "Prano",
