@@ -6,10 +6,10 @@ OC.L10N.register(
     "We wanted to inform you that %s has published the calendar »%s«." : "Желимо да Вас обавестимо да је %s објавио календар »%s«.",
     "Open »%s«" : "Отвори »%s«",
     "Cheers!" : "Здраво!",
+    "Calendar" : "Календар",
     "Confirm" : "Потврди",
     "Date:" : "Датум:",
     "Where:" : "Место:",
-    "Calendar" : "Календар",
     "A Calendar app for Nextcloud" : "Календар апликација за Некстклауд",
     "New event" : "Нови догађај",
     "Today" : "Данас",
@@ -29,6 +29,7 @@ OC.L10N.register(
     "Deleted" : "Обрисано",
     "Restore" : "Врати",
     "Delete permanently" : "Обриши заувек",
+    "Empty trash bin" : "Испразни корпу за отпатке",
     "Share link" : "Дели везу",
     "Delete share link" : "Обриши везу дељења",
     "can edit" : "може да мења",
@@ -48,6 +49,7 @@ OC.L10N.register(
     "Description" : "Опис",
     "Duration" : "Трајање",
     "to" : "за",
+    "Delete slot" : "Обриши прорез",
     "Add" : "Додај",
     "Monday" : "Понедељак",
     "Tuesday" : "Уторак",
@@ -61,7 +63,11 @@ OC.L10N.register(
     "Your email address" : "Адреса Ваше е-поште",
     "Notification" : "Обавештење",
     "Email" : "Е-пошта",
+    "Delete file" : "Обриши фајл",
+    "Choose a file to add as attachment" : "Изаберите фајл за прилог",
+    "Choose a file to share as a link" : "Одаберите фајл који желите да поделите као везу",
     "Available" : "Доступно",
+    "Not available" : "Није доступно",
     "Busy" : "Заузет",
     "Unknown" : "Непознато",
     "Accept" : "Прихвати",
@@ -72,6 +78,8 @@ OC.L10N.register(
     "Repeat" : "Понављај",
     "never" : "никада",
     "after" : "након",
+    "first" : "прва",
+    "last" : "последња",
     "available" : "доступно",
     "More" : "Остало",
     "Global" : "Цео свет",
@@ -81,6 +89,7 @@ OC.L10N.register(
     "[Tomorrow]" : "[Сутра]",
     "[Yesterday]" : "[Јуче]",
     "Details" : "Детаљи",
+    "Invite" : "Позив",
     "Attendees" : "Присутни",
     "Resources" : "Ресурси",
     "Close" : "Затвори",
@@ -102,6 +111,7 @@ OC.L10N.register(
     "Canceled" : "Отказано",
     "Categories" : "Категорије",
     "Add this as a new category" : "Додај ово као нову категорију",
+    "Error while sharing file" : "Грешка приликом дељења фајла",
     "An error occurred, unable to delete the calendar." : "Догодила се грешка, не могу да обришем календар.",
     "Money" : "Новац",
     "Talk" : "Разговор",
